package de.hszg.fei.svBeispiel;

import java.util.ArrayList;
import java.util.Random;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.view.View;

class Circle {
	private static Random random = new Random();
	
	private int x;
	private int y;
	private int radius;
	private int color;
	
	private Circle(int x, int y, int radius, int color) {
		this.x = x;
		this.y = y;
		this.radius = radius;
		this.color = color;
	}
	
	static Circle randomCircle(int color) {
		int x = random.nextInt(SampleView.WIDTH - 20);
		int y = random.nextInt(SampleView.HEIGHT - 20);
		int radius = 10 + random.nextInt(10);
		
		return new Circle(x,y,radius, color);
	}
	
	int getX() { return this.x; }
	int getY() { return this.y; }
	int getRadius() { return this.radius; }
	int getColor() { return this.color; }
}

public class SampleView extends View {
	
	public static final int WIDTH = 320;
	public static final int HEIGHT = 240;
	public static final int HEIGHTCOLOR = 80;
	
	private int color;
	private ArrayList<Circle> circles;
	
	private Paint backgroundPaint;
	private Paint bgcolorPaint;
	private Paint colorPaint;
	private Paint circlePaint;

	public SampleView(Context context) {
		super(context);
		
		init();
	}

	public SampleView(Context context, AttributeSet attrs) {
		super(context, attrs);
		
		init();
	}

	public SampleView(Context context, AttributeSet attrs, int defStyle) {
		super(context, attrs, defStyle);
		
		init();
	}
	
	private void init() {
		this.backgroundPaint = new Paint(Paint.ANTI_ALIAS_FLAG);
		this.backgroundPaint.setColor(Color.WHITE);
		
		this.bgcolorPaint = new Paint(Paint.ANTI_ALIAS_FLAG);
		this.bgcolorPaint.setColor(Color.BLACK);
		
		this.colorPaint = new Paint(Paint.ANTI_ALIAS_FLAG);
		
		this.circlePaint = new Paint(Paint.ANTI_ALIAS_FLAG);
		
		this.circles = new ArrayList<Circle>();
	}
	
	protected void onMeasure(int wSpec, int hSpec) {
		setMeasuredDimension(WIDTH,HEIGHT+HEIGHTCOLOR);
	}
	
	protected void onDraw(Canvas canvas) {
		int       height = this.getMeasuredHeight();
		int       width = this.getMeasuredWidth();
		Circle    circle;
		
		canvas.drawRect(0, 0, WIDTH, HEIGHT, this.backgroundPaint);
		canvas.drawRect(0, HEIGHT, width, HEIGHT+HEIGHTCOLOR, this.bgcolorPaint);
		
		this.colorPaint.setColor(this.color);
		canvas.drawRect(20, HEIGHT+10, width-20, HEIGHT+HEIGHTCOLOR-10, this.colorPaint);
		
		for (int i=0 ; i<this.circles.size() ; i++) {
			circle = this.circles.get(i);
			this.circlePaint.setColor(circle.getColor());
			canvas.drawCircle(circle.getX(), circle.getY(), circle.getRadius(), this.circlePaint);
		}
	}
	
	public void setColor(int color) {
		this.color = color;
		this.invalidate();
	}
	
	public void newCircle() {
		this.circles.add(Circle.randomCircle(this.color));
		this.invalidate();
	}
	
	public void clearCircles() {
		this.circles.clear();
		this.invalidate();
	}

}
